pub struct ApprovedPayload {
pub service_id: Uuid,
}Expand description
Payload for approval notification.
Pushed by the controller as soon as an admin approves the service — the service
does not poll for this; it simply waits on the still-open enrollment connection
(or a reconnect made with the enrollment_secret bearer token). On receipt, the
service proceeds to generate a keypair and send request_certificate.
Fields
service_id: UuidTrait Implementations
Sourceimpl Clone for ApprovedPayload
impl Clone for ApprovedPayload
Sourcefn clone(&self) -> ApprovedPayload
fn clone(&self) -> ApprovedPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApprovedPayload
impl Debug for ApprovedPayload
Sourceimpl<'de> Deserialize<'de> for ApprovedPayload
impl<'de> Deserialize<'de> for ApprovedPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ApprovedPayload
Sourceimpl PartialEq for ApprovedPayload
impl PartialEq for ApprovedPayload
Sourceimpl Serialize for ApprovedPayload
impl Serialize for ApprovedPayload
impl StructuralPartialEq for ApprovedPayload