pub struct CaBundleUpdatedPayload {
pub ca_bundle_pem: String,
}Expand description
Payload for CA bundle update notification.
Pushed by the controller when the CA certificate bundle changes (e.g. after CA
rotation). The service should update its trust store with the new bundle PEM
and prepare for certificate renewal (see RequestCertRenewalPayload).
Fields
ca_bundle_pem: StringTrait Implementations
Sourceimpl Clone for CaBundleUpdatedPayload
impl Clone for CaBundleUpdatedPayload
Sourcefn clone(&self) -> CaBundleUpdatedPayload
fn clone(&self) -> CaBundleUpdatedPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaBundleUpdatedPayload
impl Debug for CaBundleUpdatedPayload
Sourceimpl<'de> Deserialize<'de> for CaBundleUpdatedPayload
impl<'de> Deserialize<'de> for CaBundleUpdatedPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CaBundleUpdatedPayload
Sourceimpl PartialEq for CaBundleUpdatedPayload
impl PartialEq for CaBundleUpdatedPayload
Sourceimpl Serialize for CaBundleUpdatedPayload
impl Serialize for CaBundleUpdatedPayload
impl StructuralPartialEq for CaBundleUpdatedPayload
Sourceimpl WireValidate for CaBundleUpdatedPayload
impl WireValidate for CaBundleUpdatedPayload
Sourcefn wire_validate(&self) -> Result<(), WireValidationError>
fn wire_validate(&self) -> Result<(), WireValidationError>
Validate that all fields are within wire protocol size limits.