pub struct CheckVersionsPayload {
pub host_machine_id: String,
pub assignments: Vec<VersionCheckAssignment>,
}Expand description
Payload for requesting version checks from the agent.
Fields
host_machine_id: StringThe machine_id of the host to check versions on.
For the regular agent (one service = one host), the agent validates that this matches its own machine_id as a defensive sanity check. For the SSH agent (one service = N remote hosts), the agent uses this field to look up the correct SSH credentials and route the operation to the right remote host.
assignments: Vec<VersionCheckAssignment>List of software items to check.