#[non_exhaustive]pub struct ServiceConfigKey {
pub tenant_id: Option<Uuid>,
pub key: String,
}Expand description
Identifies a service config entry by scope and key (used in delete notifications).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tenant_id: Option<Uuid>Tenant this entry belongs to, or None for global entries.
key: StringEntry key.
Implementations