pub struct UpdateOutputPayload {
pub update_history_id: Uuid,
pub output: String,
pub stream: OutputStreamType,
}Expand description
Agent -> Controller: Streaming output line.
Fields
update_history_id: Uuidoutput: Stringstream: OutputStreamTypeTrait Implementations
Sourceimpl Clone for UpdateOutputPayload
impl Clone for UpdateOutputPayload
Sourcefn clone(&self) -> UpdateOutputPayload
fn clone(&self) -> UpdateOutputPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateOutputPayload
impl Debug for UpdateOutputPayload
Sourceimpl<'de> Deserialize<'de> for UpdateOutputPayload
impl<'de> Deserialize<'de> for UpdateOutputPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UpdateOutputPayload
Sourceimpl PartialEq for UpdateOutputPayload
impl PartialEq for UpdateOutputPayload
Sourcefn eq(&self, other: &UpdateOutputPayload) -> bool
fn eq(&self, other: &UpdateOutputPayload) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UpdateOutputPayload
impl Serialize for UpdateOutputPayload
impl StructuralPartialEq for UpdateOutputPayload
Sourceimpl WireValidate for UpdateOutputPayload
impl WireValidate for UpdateOutputPayload
Sourcefn wire_validate(&self) -> Result<(), WireValidationError>
fn wire_validate(&self) -> Result<(), WireValidationError>
Validate that all fields are within wire protocol size limits.