pub struct VersionCheckAssignment {
pub software_item_id: Uuid,
pub name: String,
pub detect_version: Option<PluginAssignment>,
pub fetch_releases: Option<PluginAssignment>,
pub host_software_item_id: Option<Uuid>,
}Expand description
A single software item to check for installed version and/or latest version.
Fields
software_item_id: UuidSoftware item ID.
name: StringHuman-readable name for logging.
detect_version: Option<PluginAssignment>Plugin for the detect_version role. None if no detect_version plugin is configured for this host-software pair.
fetch_releases: Option<PluginAssignment>Plugin for the fetch_releases role — only included for agent-side plugins (i.e., plugins without ControllerSideFetchReleases or with execution_site = agent). Controller-side fetch_releases is handled by the scheduler, not sent to the agent.
host_software_item_id: Option<Uuid>Host software item ID for routing results to the host_software_items table. When set, this assignment is for a host-managed software item rather than a targeted software item.