#[non_exhaustive]pub struct WorkloadReleasePayload {
pub keys: BTreeSet<String>,
}Expand description
Service → Controller: voluntarily release config keys.
Sent when a service no longer wants to serve certain configs (e.g. after a config deletion). The controller releases the keys and makes them available for other services.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.keys: BTreeSet<String>Config keys to release.
Implementations