#[non_exhaustive]pub enum InteractionHttpMethod {
Get,
Post,
Put,
Delete,
Other(String),
}Expand description
HTTP method a surface interaction is dispatched with (REST method model, B1).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Get
Post
Put
Delete
Other(String)
An unknown value received from a newer peer.
The inner string is the raw value as it appeared on the wire.
Implementations