#[non_exhaustive]pub enum SurfaceNode {
Section {
title: Option<String>,
header_action_ids: Vec<InteractionId>,
children: Vec<SurfaceNode>,
},
TextBlock {
text: String,
},
KeyValue {
data_source_id: DataSourceId,
},
Table {
data_source_id: DataSourceId,
columns: Vec<SurfaceTableColumn>,
row_actions: Vec<SurfaceTableRowAction>,
},
Form {
interaction_id: InteractionId,
http_method: Option<InteractionHttpMethod>,
},
ActionBar {
action_ids: Vec<ActionRef>,
},
Tabs {
tabs: Vec<SurfaceTab>,
},
Callout {
level: CalloutLevel,
text: String,
},
EmptyState {
title: String,
description: Option<String>,
},
ModalTrigger {
interaction_id: InteractionId,
http_method: Option<InteractionHttpMethod>,
modal_nodes: Vec<SurfaceNode>,
},
WorkflowTrigger {
interaction_id: InteractionId,
step_nodes: Vec<SurfaceNode>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Section
TextBlock
KeyValue
Fields

data_source_id: DataSourceIdTable
Fields

data_source_id: DataSourceId
columns: Vec<SurfaceTableColumn>
row_actions: Vec<SurfaceTableRowAction>Form
ActionBar
Tabs
Fields

tabs: Vec<SurfaceTab>Callout
EmptyState
ModalTrigger
Fields

interaction_id: InteractionId
http_method: Option<InteractionHttpMethod>
modal_nodes: Vec<SurfaceNode>WorkflowTrigger
Implementations
Sourceimpl SurfaceNode
impl SurfaceNode
Sourcepub fn section(
title: Option<impl Into<String>>,
children: Vec<SurfaceNode>,
) -> SurfaceNode
pub fn section( title: Option<impl Into<String>>, children: Vec<SurfaceNode>, ) -> SurfaceNode
Constructs a SurfaceNode::Section with an optional title and children,
and no header action buttons.
Use this constructor instead of the struct literal because SurfaceNode is
#[non_exhaustive] — external crates cannot construct variants directly.
Sourcepub fn section_with_header_actions(
title: Option<impl Into<String>>,
header_action_ids: Vec<InteractionId>,
children: Vec<SurfaceNode>,
) -> SurfaceNode
pub fn section_with_header_actions( title: Option<impl Into<String>>, header_action_ids: Vec<InteractionId>, children: Vec<SurfaceNode>, ) -> SurfaceNode
Constructs a SurfaceNode::Section with an optional title, header action
button IDs, and children.
header_action_ids refers to crate::InteractionIds that the Dashboard
renders as icon buttons in the section header row.
Use this constructor instead of the struct literal because SurfaceNode is
#[non_exhaustive] — external crates cannot construct variants directly.