current_trace_context

Function current_trace_context 

pub fn current_trace_context() -> TraceContext
Returns the trace context for the current execution context.

Currently generates a new random trace context. When tracing-opentelemetry is wired in, this function will extract trace/span IDs from the current span context, making all existing propagation plumbing light up automatically.