Skip to main contentModule envelope
Source - ControllerEnvelope
- Envelope wrapping a
ControllerMessage with a monotonically increasing
sequence number for replay protection and the current protocol version. - IncomingSeq
- Validates incoming sequence numbers for a single direction of a WebSocket
connection. Expects messages to arrive as 1, 2, 3, …
- OutgoingSeq
- Tracks outgoing sequence numbers for a single direction of a WebSocket
connection. Assigns monotonically increasing numbers starting at 1.
- ReportPagination
- Pagination metadata for a paginated report.
- SeqError
- Error returned when a received sequence number does not match the expected
value.
- ServiceEnvelope
- Envelope wrapping a
ServiceMessage with a monotonically increasing
sequence number for replay protection and the current protocol version.
- CURRENT_PROTOCOL_VERSION
- The current wire protocol version stamped on every envelope.